package com.ynet.life.image;

import com.ynet.life.base.LifeStandard;
import java.awt.Color;
import java.awt.Font;
import java.awt.Graphics2D;
import java.awt.geom.AffineTransform;
import java.awt.image.BufferedImage;
import java.util.HashSet;
import java.util.Random;

/* loaded from: com_ynet_life_image.jar:com/ynet/life/image/ImageGenerator.class */
public class ImageGenerator {
    private static BufferedImage DEFAULT_BACKGROUND;
    private static final int CHINESE_FONT_WIDTH = 16;
    private static final int CHINESE_FONT_HEIGHT = 16;
    private static final int NUMBER_WIDTH = 13;
    private static final int NUMBER_HEIGHT = 10;
    private BufferedImage image;
    private int currentX = 5;
    private int currentY = NUMBER_HEIGHT;
    private int imageWidth;
    private int imageHeight;
    private static final Font CHINESE_FONT = new Font("宋体", 1, 16);
    private static final Font NUNBER_FONT = new Font("宋体", 1, 16);
    private static final Color TITLE_FONT_COLOR = Color.GRAY;
    private static final Color CONTENT_FONT_COLOR = Color.GRAY;
    private static final Color CONTENT_FONT_COLOR_STRONG = Color.YELLOW;

    public ImageGenerator(int imageWidth, int imageHeight) {
        this.imageWidth = imageWidth;
        this.imageHeight = imageHeight;
    }

    private void checkBackground() {
        if (this.image == null) {
            if (DEFAULT_BACKGROUND != null) {
                this.image = getBackground();
                return;
            }
            this.image = new BufferedImage(this.imageWidth, this.imageHeight, 1);
            Graphics2D graphic = this.image.getGraphics();
            graphic.setColor(new Color(14411752));
            graphic.fillRect(0, 0, this.imageWidth, this.imageHeight);
            String background = LifeStandard.getBankSettingsValue("ImageBackground");
            graphic.setColor(Color.LIGHT_GRAY);
            graphic.setFont(new Font("隶书", 0, 24));
            int f = 0;
            int k = this.imageHeight / background.length();
            for (int i = 0; i < this.imageWidth; i += 20) {
                graphic.drawString(background.substring(f % background.length(), (f % background.length()) + 1), f * 20, (k + (k * (f % background.length()))) - 5);
                f++;
            }
            graphic.setFont(new Font("宋体", 0, 14));
            Random random = new Random();
            for (int i2 = 0; i2 < this.imageWidth; i2++) {
                int x = random.nextInt(this.imageWidth);
                int y = random.nextInt(this.imageHeight);
                graphic.drawOval(x, y, 2, 0);
            }
        }
    }

    public void addLine(String title, String content, boolean containCode, HashSet positionSet, String colorStr, boolean colorFlag, String subTitle) {
        checkBackground();
        Graphics2D graphic = this.image.getGraphics();
        graphic.setTransform(new AffineTransform());
        graphic.setColor(TITLE_FONT_COLOR);
        graphic.setFont(CHINESE_FONT);
        graphic.drawString(title, this.currentX, this.currentY + 16);
        int contextX = this.currentX + (title.length() << 4);
        if (!containCode) {
            if (colorFlag) {
                if ("0".equals(colorStr)) {
                    graphic.setColor(Color.MAGENTA);
                } else if ("1".equals(colorStr)) {
                    graphic.setColor(Color.RED);
                } else if ("2".equals(colorStr)) {
                    graphic.setColor(Color.BLUE);
                } else if ("3".equals(colorStr)) {
                    graphic.setColor(Color.GREEN);
                }
                graphic.setFont(new Font("宋体", 1, 24));
                graphic.drawString(content, contextX, this.currentY + 16);
                contextX = contextX + (content.length() * 24) + 3;
            } else {
                graphic.setColor(TITLE_FONT_COLOR);
                graphic.setFont(CHINESE_FONT);
                graphic.drawString(content, contextX, this.currentY + 16);
            }
            if (!"".equals(subTitle)) {
                graphic.setColor(TITLE_FONT_COLOR);
                graphic.setFont(CHINESE_FONT);
                graphic.drawString(subTitle, contextX, this.currentY + 16);
            }
        } else {
            for (int i = 0; i < content.length(); i++) {
                if (containCode && positionSet.contains(Integer.valueOf(i))) {
                    if ("0".equals(colorStr)) {
                        graphic.setColor(Color.MAGENTA);
                    } else if ("1".equals(colorStr)) {
                        graphic.setColor(Color.RED);
                    } else if ("2".equals(colorStr)) {
                        graphic.setColor(Color.BLUE);
                    } else if ("3".equals(colorStr)) {
                        graphic.setColor(Color.GREEN);
                    }
                    graphic.setFont(new Font("宋体", 1, 24));
                } else {
                    graphic.setColor(CONTENT_FONT_COLOR);
                    graphic.setFont(NUNBER_FONT);
                }
                int charX = contextX + (i * NUMBER_WIDTH);
                int charY = this.currentY + 15;
                int i2 = i;
                graphic.drawString(content.substring(i2, i2 + 1), charX, charY);
            }
        }
        this.currentX = 5;
        this.currentY += 32;
    }

    public BufferedImage getImage() {
        return this.image;
    }

    public BufferedImage getBackground() {
        BufferedImage clonedBg = new BufferedImage(DEFAULT_BACKGROUND.getWidth(), DEFAULT_BACKGROUND.getHeight(), DEFAULT_BACKGROUND.getType());
        clonedBg.setData(DEFAULT_BACKGROUND.getData());
        return clonedBg;
    }

    public static void setBackground(BufferedImage background) {
        DEFAULT_BACKGROUND = background;
    }
}
